@@ -20,19 +20,9 @@ Base utilities to build API operation managers and objects on top of.
 import abc
 import copy
 
-import six
-
 from muranoclient.apiclient import exceptions
 
 
-# Python 2.4 compat
-try:
-    all
-except NameError:
-    def all(iterable):
-        return True not in (not x for x in iterable)
-
-
 def getid(obj):
     """Get obj's id or object itself if no id
 
@@ -126,8 +116,7 @@ class Manager(object):
         return self.resource_class(self, body)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ManagerWithFind(Manager):
+class ManagerWithFind(Manager, metaclass=abc.ABCMeta):
     """Manager with additional `find()`/`findall()` methods."""
 
     @abc.abstractmethod
