@@ -13,8 +13,8 @@
 import collections
 import json
 import tempfile
+from unittest import mock
 
-import mock
 
 from muranoclient.osc.v1 import environment as osc_env
 from muranoclient.tests.unit.osc.v1 import fakes
@@ -537,7 +537,7 @@ class TestEnvironmentModelShow(TestEnvironment):
         self.assertEqual(expected_columns, columns)
 
         # Check that data is correct
-        self.assertItemsEqual(ENV_MODEL.values(), data)
+        self.assertCountEqual(ENV_MODEL.values(), data)
 
     def test_environment_model_show_full(self):
         arglist = ['env-id', '--path', '/path', '--session-id', 'sess-id']
@@ -551,7 +551,7 @@ class TestEnvironmentModelShow(TestEnvironment):
         self.assertEqual(expected_columns, columns)
 
         # Check that data is correct
-        self.assertItemsEqual(ENV_MODEL.values(), data)
+        self.assertCountEqual(ENV_MODEL.values(), data)
 
 
 class TestEnvironmentModelEdit(TestEnvironment):
@@ -581,4 +581,4 @@ class TestEnvironmentModelEdit(TestEnvironment):
         self.assertEqual(expected_columns, columns)
 
         # Check that data is correct
-        self.assertItemsEqual(ENV_MODEL.values(), data)
+        self.assertCountEqual(ENV_MODEL.values(), data)
